summaryrefslogtreecommitdiffstats
path: root/pkg/utils/utils.go
diff options
context:
space:
mode:
authorJesse Duffield <jessedduffield@gmail.com>2018-08-13 21:16:21 +1000
committerJesse Duffield <jessedduffield@gmail.com>2018-08-13 21:16:21 +1000
commit9e725ae24e8fcecefec35a65b50476d371653ffb (patch)
tree840df3748f981967a3b9f7c276602832dab360d3 /pkg/utils/utils.go
parent97cff656121270e9c790432e28622d92ab7b0f1a (diff)
got this bad boy compiling again
Diffstat (limited to 'pkg/utils/utils.go')
-rw-r--r--pkg/utils/utils.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/pkg/utils/utils.go b/pkg/utils/utils.go
index b3efcc2db..68438246a 100644
--- a/pkg/utils/utils.go
+++ b/pkg/utils/utils.go
@@ -46,8 +46,8 @@ func ColoredStringDirect(str string, colour *color.Color) string {
return colour.SprintFunc()(fmt.Sprint(str))
}
-// GetCurrentProject gets the repo's base name
-func GetCurrentProject() string {
+// GetCurrentRepoName gets the repo's base name
+func GetCurrentRepoName() string {
pwd, err := os.Getwd()
if err != nil {
log.Fatalln(err.Error())